#!/usr/bin/perl -w
use strict;
use lib qw/inc/;
use ExtUtils::MakeMaker;
use CTK;
use CTK::Util qw/sharedir/;
use File::Spec;
use MY;

my $build_requires = {
        'ExtUtils::MakeMaker'   => 6.60,
        'Test::More'            => 0.94,
    };

my $prereq_pm = {
        'AnyEvent'              => 7.07,    # sudo apt install libanyevent-perl
        'CGI'                   => 4.40,
        'CTK'                   => 2.05,
        'Fatal'                 => 0,       # For XML::Simple only!
        'File::Copy::Recursive' => 0.3,     # sudo apt install libfile-copy-recursive-perl
        'HTTP::Message'         => 6.06,    # sudo apt install libhttp-message-perl
        'IO::Interface'         => 0,       # sudo apt install libio-interface-perl
        'IO::Socket::INET'      => 0,
        'JSON'                  => 2.17,    # sudo apt install libjson-perl
        'Module::Loaded'        => 0.08,
        'Mojolicious'           => 7.94,    # sudo apt install libmojolicious-perl (sudo yum install perl-Mojolicious)
        'Proc::ProcessTable'    => 0.48,    # sudo apt install libproc-processtable-perl (sudo yum install perl-Proc-ProcessTable)
        'RRDs'                  => 1.50,    # sudo apt install rrdcached librrds-perl
        'Time::Local'           => 0,
        'Text::ParseWords'      => 3.01,
        'URI'                   => 0,       # sudo apt install liburi-perl
    };

my $exefiles = [qw(
        bin/cetus
        bin/visd
    )];

my $ctk = new CTK( project => 'VISD' );
WriteMakefile(
    'NAME'              => 'VISD',
    'MIN_PERL_VERSION'  => 5.016001,
    'VERSION_FROM'      => 'lib/VISD.pm',
    'ABSTRACT_FROM'     => 'lib/VISD.pm',
    'XS_VERSION'        => "1.03",
    'BUILD_REQUIRES'    => $build_requires,
    'PREREQ_PM'         => $prereq_pm,
    'EXE_FILES'         => $exefiles,
    'AUTHOR'            => 'Serz Minus (Sergey Lepenkov) <abalama@cpan.org>',
    'LICENSE'           => 'perl',
    'META_MERGE'        => {
        resources => {
            homepage        => 'https://sourceforge.net/projects/visd/',
            repository      => 'https://svn.code.sf.net/p/visd/code/trunk',
            license         => 'https://dev.perl.org/licenses',
        },
    },
    macro => {
            PROJECT_NAME    => 'VISD',
            PROJECT_NAMEL   => 'visd',
            PROJECT_CONFDIR => '$(DESTDIR)' . $ctk->root,
            PROJECT_WWWDIR => '$(DESTDIR)' . File::Spec->catdir(sharedir(), $ctk->prefix, "www"),
        },
    clean => {
            FILES => '$(INST_CONF) *.tmp *.rrd',
        },
);

1;

__END__
