/*  $Id: main.js 7 2019-03-05 16:15:00Z minus $
 *
 *  main.js
 *  Version 1.03 2020
 *  Global definitions and common utilities
 *                                                       ____________
 *  Copyright (C) 1998-2019 D&D Corporation.             \          /
 *  All rights reserved.                                  \________/
 *  Sergey Lepenkov (Serż Minus), http://www.serzik.com    \      /
 *                                                          \____/
 *  Dual licensed under the MIT and GNU GPL v3. licenses:    \  /
 *   http://www.opensource.org/licenses/mit-license.php       \/
 *   http://www.gnu.org/licenses/gpl.html
 *
*/

$(document).ready(function(){
    /* Tooltips */
    $( ".tooltip" ).tooltip();
    $('[data-toggle="tooltip"]').tooltip();
});

/*
    Constants
*/

const PROJECT_PREFIX = "VISD";
const JQX_TIMEOUT = 2*60*1000; // 2 minutes
const JQX_PFX_URL = "/cetus-data";
const LAST_DATA_EXPIRES = 60*3; // 3 mins
const ajaxDefaults = { // For Ajax statuses
    status_code: 200,
    status_text: "OK",
    code: 0,
    message: "OK",
};

/*
    Utilities
*/

function timeConverter(UNIX_timestamp){
    var a = new Date(UNIX_timestamp * 1000);
    var months = ['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'];
    var year = a.getFullYear();
    var month = months[a.getMonth()];
    var date = a.getDate();
    var hour = ('0' + a.getHours()).slice(-2);
    var min = ('0' + a.getMinutes()).slice(-2);
    var sec = ('0' + a.getSeconds()).slice(-2)
    var time = date + ' ' + month + ' ' + year + ' ' + hour + ':' + min + ':' + sec ;
    return time;
}
function dtf(u) { // Unixtime
    var dt = u ? (new Date(u * 1000)) : new Date();
    var year    = dt.getFullYear();
    var month   = ('0' + (dt.getMonth() + 1)).slice(-2);
    var day     = ('0' + dt.getDate()).slice(-2);
    var hour    = ('0' + dt.getHours()).slice(-2);
    var min     = ('0' + dt.getMinutes()).slice(-2);
    var sec     = ('0' + dt.getSeconds()).slice(-2)
    //return day + '.' + month + '.' + year + ' ' + hour + ':' + min; //  + ':' + sec
    return year + '-' + month + '-' + day + ' ' + hour + ':' + min + ':' + sec;
}
function dtf_short(u) { // Unixtime
    var dt = u ? (new Date(u * 1000)) : new Date();
    var months = ['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'];
    var year    = dt.getFullYear();
    //var month   = ('0' + (dt.getMonth() + 1)).slice(-2);
    var month = months[dt.getMonth()];
    var day     = ('0' + dt.getDate()).slice(-2);
    var hour    = ('0' + dt.getHours()).slice(-2);
    var min     = ('0' + dt.getMinutes()).slice(-2);
    var sec     = ('0' + dt.getSeconds()).slice(-2)
    return day + ' ' + month + ' ' + hour + ':' + min + ':' + sec;
}
function fduration(msecs){
    var secs = Math.trunc((msecs || 0)*1);
    var years = Math.trunc(secs / (60*60*24*365));
    secs -= years * 60*60*24*365;
    var days = Math.trunc(secs / (60*60*24));
    secs -= days * 60*60*24;
    var hours = Math.trunc(secs / (60*60));
    secs -= hours * 60*60;
    var mins = Math.trunc(secs / 60);
    secs = secs % 60;

    if (years) {
        return years + " years "+ days +" days " + hours + " hours";
    } else if (days) {
        return days + " days " + hours + " hours " + mins + " minutes";
    } else if (hours) {
        return hours + " hours " + mins + " minutes " + secs + " seconds";
    } else if (mins >= 2) {
        return mins + " minutes " + secs + " seconds";
    } else if (secs > 5) {
        secs += mins * 60;
        return secs + " seconds";
    } else if (msecs - secs) {
        return msecs + " seconds";
    } else {
        return secs + " seconds";
    }
}
function digsf(inv){
    invs = inv + "";
    return invs.replace(/(\d)(?=(\d\d\d)+([^\d]|$))/g, "$1`");
}
function formatBytes(bytes,decimals) {
   if(bytes == 0) return '0 Bytes';
   var k = 1024,
       dm = decimals <= 0 ? 0 : decimals || 2,
       sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
       i = Math.floor(Math.log(bytes) / Math.log(k));
   return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
}
function compressIPV6(input) {
    var formatted = input.replace(/\b(?:0+:){2,}/, ':');
    var finalAddress = formatted.split(':')
        .map(function(octet) {
            return  octet.replace(/\b0+/g, '');
        }).join(':');
    if (finalAddress === ":") return "::";
    return finalAddress;
}
function mask2cidr(mask){
    var cidr = ''
    for (m of mask.split('.')) {
        if (parseInt(m) > 255) { // Check each group is 0-255
            console.log('ERROR: Invalid Netmask');
            return undefined;
        }
        if (parseInt(m) > 0 && parseInt(m) < 128) {
            console.log('ERROR: Invalid Netmask');
            return undefined;
        }
        cidr += (m >>> 0).toString(2)
    }
    return cidr.split('1').length-1
}
function getBIT(v,n){
    if (!v) v = 0;
    if (!n) n = 0;
    return (v & (1 << n)) ? 1 : 0;
}
function setBIT(v,n){
    if (!v) v = 0;
    if (!n) n = 0;
    return (v | Math.pow(2,n));
}
function unsetBIT(v,n){
    if (!v) v = 0;
    if (!n) n = 0;
    return (v ^ Math.pow(2,n));
}
function validateEmail(email) {
    var reg = /^\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$/;
    if (reg.test(email)) {
        return true;
    }
    return false;
}
function statusf(i) {
    if (_.isNumber(i) && !_.isNaN(i)) {
        if (i == -1) {
            return "warning";
        } else if (i == 0) {
            return "critical";
        } else if (i == 1) {
            return "good";
        }
    }
    return "unknown";
}
function status_color(i) {
    if (_.isNumber(i) && !_.isNaN(i)) {
        if (i == -1) {
            return "warning";
        } else if (i == 0) {
            return "danger";
        } else if (i == 1) {
            return "body";
        }
    }
    return "muted";
}

/* __END__ */
